import requests
import hashlib
import json
import time
import flask
from flask_cors import CORS
import os

app = flask.Flask(__name__)
CORS(app)

token = os.environ.get("AFDIAN_TOKEN")


@app.route("/")
def get_sponsor_list():
	# 从请求参数中获取user_id
	user_id = flask.request.args.get("user_id")
	
	# 构造请求参数
	params = {
		"page": 1
	}
	# 转换为JSON字符串
	params_str = json.dumps(params)
	
	# 获取当前时间戳
	ts = int(time.time())
	
	# 构造签名
	sign = hashlib.md5(f"{token}params{params_str}ts{ts}user_id{user_id}".encode()).hexdigest()
	
	# 构造请求数据
	data = {
		"user_id": user_id,
		"params": params_str,
		"ts": ts,
		"sign": sign
	}
	
	# 发送请求
	url = "https://afdian.net/api/open/query-sponsor"
	response = requests.post(url, json=data)
	
	# 处理响应
	if response.status_code == 200:
		result = response.json()
		if result["ec"] == 200:
			sponsors = result["data"]["list"]
			sponsor_list = []
			for sponsor in sponsors:
				user = sponsor["user"]
				sponsor_user_id = user["user_id"]
				username = user["name"]
				avatar = user["avatar"]
				sponsor_info = {
					"user_id": sponsor_user_id,
					"name": username,
					"avatar": avatar
				}
				sponsor_list.append(sponsor_info)
			
			return {"ec": 200, "data": {"list": sponsor_list}}
		else:
			error_msg = result["em"]
			ec = result["ec"]
			return {"ec": ec, "msg": error_msg}
	else:
		return {"ec": 500, "Error": "Failed to retrieve sponsor list"}


if __name__ == "__main__":
	app.run(host="0.0.0.0", port=12597)
